/***********************************************************************
 *                copyright 2001, Amoco Production Company             *
 *                            All Rights Reserved                      *
 *                    an affiliate of BP America Inc.                  *
 ***********************************************************************/
#ifdef __MSDOS__

#include <dos.h>
int c_break()
{
	exitprocandexit(2);
	return 1;
}
void interruptOnBreak()
{	ctrlbrk(c_break);	}

#else

void interruptOnBreak()
{	return;	}

#endif

#include <stdio.h>
#include <stdlib.h>
#include "ufh.h"

extern int yydebug;
extern int printSymbols;

int main(argc, argv)
int argc;
char *argv[];
{
    static char *stdinonly[] = { "-" };
    extern int gargc;
    extern char** gargv;
    extern char    *progname;

    int c;
    static char* optstring = "vs";
    extern char* optarg;
    extern int optind;
    int files = 0;

#ifdef ENABLE_DEBUGGING
    yydebug = 1;
#endif
    interruptOnBreak();
    progname = argv[0];

    while((c = getopt(argc, argv, optstring)) != -1)
	switch(c) {
	  case 'v':
	    verbose = 1;
	    break;
	  case 's':
	    printSymbols = 1;
	    break;
	  default:
	    break;
	}

    if(optind >= argc) {
	fprintf(stderr, "ufh: nothing to do (no program).\n");
	return (1);
    } else {
	gargv = argv + optind;
	gargc = argc - optind;
    }
    init();
    return run();
}

